@@ -106,14 +106,15 @@ GRP.default <- function(X, by = NULL, sort = .op[["sort"]], decreasing = FALSE,
       } else if(is.character(by)) {
         namby <- by
         by <- ckmatch(by, attr(X, "names"))
-      } else if(is.numeric(by)) {
-        by <- as.integer(by)
+      } else {
+        by <- if(is.numeric(by)) as.integer(by) else if(is.logical(by)) which(by) else if(is.function(by)) which(vapply(unattrib(X), by, TRUE)) else
+              stop("by needs to be either a one-sided formula, character column names, column indices, a logical vector or selector function!")
         namby <- attr(X, "names")[by]
         if(is.null(namby)) {
           namby <- paste0("Group.", seq_along(by))
           attr(X, "names") <- paste0("Group.", seq_along(unclass(X))) # best ?
         }
-      } else stop("by needs to be either a one-sided formula, character column names or column indices!")
+      }
       o <- switchGRP(.subset(X, by), na.last, decreasing, return.groups || !use.group, TRUE, sort, use.group)
     }
   } else {
@@ -131,10 +132,10 @@ GRP.default <- function(X, by = NULL, sort = .op[["sort"]], decreasing = FALSE,
   if(return.groups) {
       # if unit groups, don't subset rows...
       if(length(gs) == length(o) && (use.group || sorted)) {
-        ust <- NULL
+        ust <- st
         groups <- if(is.list(X)) .Call(C_subsetCols, X, by, FALSE) else `names<-`(list(X), namby)
       } else {
-        ust <- if(use.group || sorted) st else .Call(C_subsetVector, o, st, FALSE) # o[st]
+        ust <- if(use.group || sorted) st else if(length(gs) == length(o)) o else .Call(C_subsetVector, o, st, FALSE) # o[st]
         groups <- if(is.list(X)) .Call(C_subsetDT, X, ust, by, FALSE) else
           `names<-`(list(.Call(C_subsetVector, X, ust, FALSE)), namby) # subsetVector preserves attributes (such as "label")
       }
@@ -149,7 +150,7 @@ GRP.default <- function(X, by = NULL, sort = .op[["sort"]], decreasing = FALSE,
                         groups = groups,
                         group.vars = namby,
                         ordered = c(ordered = sort, sorted = sorted),
-                        order = if(return.order && !use.group) .Call(C_setAttributes, o, ao) else NULL, # `attributes<-`(o, attributes(o)[-2L]) This does a shallow copy on newer R versions # `attr<-`(o, "group.sizes", NULL): This deep-copies it..
+                        order = if(return.order && !use.group) `attributes<-`(o, ao) else NULL, # `attributes<-`(o, attributes(o)[-2L]) This does a shallow copy on newer R versions # `attr<-`(o, "group.sizes", NULL): This deep-copies it..
                         group.starts = ust, # Does not need to be computed by group()
                         call = if(call) match.call() else NULL), "GRP"))
 }
@@ -420,6 +421,17 @@ fgroup_by <- function(.X, ..., sort = .op[["sort"]], decreasing = FALSE, na.last
 
 gby <- fgroup_by
 
+group_by_vars <- function(X, by = NULL, ...) {
+  clx <- oldClass(X)
+  oldClass(X) <- NULL
+  m <- match(c("GRP_df", "grouped_df", "data.frame"), clx, nomatch = 0L)
+  if(length(by)) by <- cols2int(by, X, names(X), FALSE)
+  attr(X, "groups") <- GRP.default(X[by], NULL, ..., call = FALSE) # Need to unclass because of sf and regrouping! (and some functions expect unclassed)
+  oldClass(X) <- c("GRP_df",  if(length(mp <- m[m != 0L])) clx[-mp] else clx, "grouped_df", if(m[3L]) "data.frame")
+  if(any(clx == "data.table")) return(alc(X))
+  X
+}
+
 print.GRP_df <- function(x, ...) {
   print(fungroup(x), ...) # better !! (the method could still print groups attribute etc. ) And can also get rid of .rows() in fgroup_by and other fuzz..
   # but better keep for now, other functions in dplyr might check this and only preserve attributes if they exist. -> Nah. select(UGA_sf, addr_cname) doesn't work anyway..
