@@ -17,7 +17,7 @@ SEXP flast_impl(SEXP x, int ng, SEXP g, int narm, int *gl) {
           break;
         }
         case STRSXP: {
-          SEXP *px = STRING_PTR(x);
+          SEXP *px = SEXPPTR(x);
           while(px[j] == NA_STRING && j != 0) --j;
           SET_STRING_ELT(out, 0, px[j]);
           break;
@@ -78,7 +78,7 @@ SEXP flast_impl(SEXP x, int ng, SEXP g, int narm, int *gl) {
         break;
       }
       case STRSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int i = ng; i--; ) pout[i] = NA_STRING;
         --pout;
         for(int i = l; i--; ) {
@@ -137,7 +137,7 @@ SEXP flast_impl(SEXP x, int ng, SEXP g, int narm, int *gl) {
         break;
       }
       case STRSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int i = ng; i--; ) pout[i] = gl[i] == NA_INTEGER ? NA_STRING : px[gl[i]];
         break;
       }
@@ -214,7 +214,7 @@ SEXP flastmC(SEXP x, SEXP Rng, SEXP g, SEXP Rnarm, SEXP Rdrop) {
         break;
       }
       case STRSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int j = 0, i = l-1; j != col; ++j) {
           while(px[i] == NA_STRING && i != 0) --i;
           pout[j] = px[i]; px += l; i = l-1;
@@ -231,7 +231,7 @@ SEXP flastmC(SEXP x, SEXP Rng, SEXP g, SEXP Rnarm, SEXP Rdrop) {
         break;
       }
       case VECSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int j = 0, i = l-1; j != col; ++j) {
           while(length(px[i]) == 0 && i != 0) --i;
           pout[j] = px[i]; px += l; i = l-1;
@@ -283,7 +283,7 @@ SEXP flastmC(SEXP x, SEXP Rng, SEXP g, SEXP Rnarm, SEXP Rdrop) {
         break;
       }
       case STRSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int i = ng * col; i--; ) pout[i] = NA_STRING;
         --pout;
         for(int j = 0; j != col; ++j) {
@@ -342,7 +342,7 @@ SEXP flastmC(SEXP x, SEXP Rng, SEXP g, SEXP Rnarm, SEXP Rdrop) {
         break;
       }
       case STRSXP: {
-        SEXP *px = STRING_PTR(x), *pout = STRING_PTR(out);
+        SEXP *px = SEXPPTR(x), *pout = SEXPPTR(out);
         for(int j = 0; j != col; ++j) {
           for(int i = ng; i--; ) pout[i] = pgl[i] == NA_INTEGER ? NA_STRING : px[pgl[i]];
           px += l; pout += ng;
