@@ -54,7 +54,7 @@ SEXP dupVecIndex(SEXP x) {
   } else if (tx == LGLSXP) {
     M = 3;
   } else error("Type %s is not supported.", type2char(tx)); // # nocov
-  int *restrict h = (int*)Calloc(M, int); // Table to save the hash values, table has size M
+  int *restrict h = (int*)R_Calloc(M, int); // Table to save the hash values, table has size M
   SEXP ans_i = PROTECT(allocVector(INTSXP, n));
   int *restrict pans_i = INTEGER(ans_i), g = 0;
   size_t id = 0;
@@ -131,7 +131,7 @@ SEXP dupVecIndex(SEXP x) {
     const double *restrict px = REAL(x);
     union uno tpv;
     for (int i = 0; i != n; ++i) {
-      tpv.d = px[i]; // R_IsNA(px[i]) ? NA_REAL : (R_IsNaN(px[i]) ? R_NaN : px[i]);
+      tpv.d = px[i]+0; // R_IsNA(px[i]) ? NA_REAL : (R_IsNaN(px[i]) ? R_NaN : px[i]);
       id = HASH(tpv.u[0] + tpv.u[1], K);
       while(h[id]) {
         if(REQUAL(px[h[id]-1], px[i])) {
@@ -157,9 +157,9 @@ SEXP dupVecIndex(SEXP x) {
       } else if (C_IsNaN(tmp)) {
         tmp.r = tmp.i = R_NaN;
       }
-      tpv.d = tmp.r;
+      tpv.d = tmp.r+0;
       u = tpv.u[0] ^ tpv.u[1];
-      tpv.d = tmp.i;
+      tpv.d = tmp.i+0;
       u ^= tpv.u[0] ^ tpv.u[1];
       id = HASH(u, K);
       while(h[id]) {
@@ -191,7 +191,7 @@ SEXP dupVecIndex(SEXP x) {
     }
   } break;
   }
-  Free(h);
+  R_Free(h);
   SEXP ngroups_sym = install("N.groups");
   setAttrib(ans_i, ngroups_sym, ScalarInteger(g));
   UNPROTECT(1);
@@ -225,7 +225,7 @@ SEXP dupVecIndexKeepNA(SEXP x) {
   } else if (tx == LGLSXP) {
     M = 3;
   } else error("Type %s is not supported.", type2char(tx)); // # nocov
-  int *restrict h = (int*)Calloc(M, int); // Table to save the hash values, table has size M
+  int *restrict h = (int*)R_Calloc(M, int); // Table to save the hash values, table has size M
   SEXP ans_i = PROTECT(allocVector(INTSXP, n));
   int *restrict pans_i = INTEGER(ans_i), g = 0;
   size_t id = 0;
@@ -295,7 +295,7 @@ SEXP dupVecIndexKeepNA(SEXP x) {
         pans_i[i] = NA_INTEGER;
         continue;
       }
-      tpv.d = px[i];
+      tpv.d = px[i]+0;
       id = HASH(tpv.u[0] + tpv.u[1], K);
       while(h[id]) {
         if(REQUAL(px[h[id]-1], px[i])) {
@@ -320,9 +320,9 @@ SEXP dupVecIndexKeepNA(SEXP x) {
         pans_i[i] = NA_INTEGER;
         continue;
       }
-      tpv.d = tmp.r;
+      tpv.d = tmp.r+0;
       u = tpv.u[0] ^ tpv.u[1];
-      tpv.d = tmp.i;
+      tpv.d = tmp.i+0;
       u ^= tpv.u[0] ^ tpv.u[1];
       id = HASH(u, K);
       while(h[id]) {
@@ -358,7 +358,7 @@ SEXP dupVecIndexKeepNA(SEXP x) {
     }
   } break;
   }
-  Free(h);
+  R_Free(h);
   SEXP ngroups_sym = install("N.groups");
   setAttrib(ans_i, ngroups_sym, ScalarInteger(g));
   UNPROTECT(1);
@@ -405,7 +405,7 @@ SEXP dupVecIndexTwoVectors(SEXP x, SEXP y) {
     }
   }
 
-  int *restrict h = (int*)Calloc(M, int), g = 0, hid = 0; // Table to save the hash values, table has size M
+  int *restrict h = (int*)R_Calloc(M, int), g = 0, hid = 0; // Table to save the hash values, table has size M
   size_t id = 0;
 
   if(both_discr) {
@@ -473,7 +473,7 @@ SEXP dupVecIndexTwoVectors(SEXP x, SEXP y) {
           union uno tpx, tpy;
           // fill hash table with indices of 'table'
           for (int i = 0; i != n; ++i) {
-            tpx.d = px[i]; tpy.d = py[i];
+            tpx.d = px[i]+0; tpy.d = py[i]+0;
             id = HASH((64988430769U * (tpx.u[0] + tpx.u[1])) + tpy.u[0] + tpy.u[1], K); // Best combination it seems
             while(h[id]) {
               hid = h[id]-1;
@@ -497,7 +497,7 @@ SEXP dupVecIndexTwoVectors(SEXP x, SEXP y) {
         const double *restrict pr = REAL_RO(tx == REALSXP ? x : y);
         union uno tpv;
         for (int i = 0; i != n; ++i) {
-          tpv.d = pr[i];
+          tpv.d = pr[i]+0;
           id = HASH((64988430769U * pi[i]) + tpv.u[0] + tpv.u[1], K); // Best combination it seems
           while(h[id]) {
             hid = h[id]-1;
@@ -517,7 +517,7 @@ SEXP dupVecIndexTwoVectors(SEXP x, SEXP y) {
         const double *restrict pr = REAL_RO(tx == REALSXP ? x : y);
         union uno tpv;
         for (int i = 0; i != n; ++i) {
-          tpv.d = pr[i];
+          tpv.d = pr[i]+0;
           id = HASH((tpv.u[0] + tpv.u[1]) * ((uintptr_t)ps[i] & 0xffffffff), K); // Best combination it seems
           while(h[id]) {
             hid = h[id]-1;
@@ -553,7 +553,7 @@ SEXP dupVecIndexTwoVectors(SEXP x, SEXP y) {
     }
   }
 
-  Free(h);
+  R_Free(h);
   SEXP ngroups_sym = install("N.groups");
   setAttrib(ans, ngroups_sym, ScalarInteger(g));
   UNPROTECT(1);
@@ -599,7 +599,7 @@ int dupVecSecond(int *restrict pidx, int *restrict pans_i, SEXP x, const int n,
   } else if (tx == LGLSXP) {
     M = (size_t)ng * 3 + 1;
   } else error("Type %s is not supported.", type2char(tx)); // # nocov
-  int *restrict h = (int*)Calloc(M, int), g = 0, hid = 0; // Table to save the hash values, table has size M
+  int *restrict h = (int*)R_Calloc(M, int), g = 0, hid = 0; // Table to save the hash values, table has size M
   size_t id = 0;
   switch (tx) {
   case LGLSXP:
@@ -655,7 +655,7 @@ int dupVecSecond(int *restrict pidx, int *restrict pans_i, SEXP x, const int n,
     const unsigned int mult = (M-1) / ng; // -1 because C is zero indexed
     union uno tpv;
     for (int i = 0; i != n; ++i) {
-      tpv.d = px[i]; // R_IsNA(px[i]) ? NA_REAL : (R_IsNaN(px[i]) ? R_NaN :px[i]);
+      tpv.d = px[i]+0; // R_IsNA(px[i]) ? NA_REAL : (R_IsNaN(px[i]) ? R_NaN :px[i]);
       id = (pidx[i]*mult) ^ HASH(tpv.u[0] + tpv.u[1], K); // HASH((tpv.u[0] + tpv.u[1]) ^ pidx[i], K) + pidx[i]; // Note: This is much faster than just adding pidx[i] to the hash value...
       while(h[id]) { // Problem: This value might be seen before, but not in combination with that pidx value...
         hid = h[id]-1; // The issue here is that REQUAL(px[hid], px[i]) could be true but pidx[hid] == pidx[i] fails, although the same combination of px and pidx could be seen earlier before...
@@ -683,9 +683,9 @@ int dupVecSecond(int *restrict pidx, int *restrict pans_i, SEXP x, const int n,
       } else if (C_IsNaN(tmp)) {
         tmp.r = tmp.i = R_NaN;
       }
-      tpv.d = tmp.r;
+      tpv.d = tmp.r+0;
       u = tpv.u[0] ^ tpv.u[1];
-      tpv.d = tmp.i;
+      tpv.d = tmp.i+0;
       u ^= tpv.u[0] ^ tpv.u[1];
       id = (pidx[i]*mult) ^ HASH(u, K);
       while(h[id]) {
@@ -720,7 +720,7 @@ int dupVecSecond(int *restrict pidx, int *restrict pans_i, SEXP x, const int n,
     }
   } break;
   }
-  Free(h);
+  R_Free(h);
   return g;
 }
 
@@ -857,7 +857,7 @@ SEXP funiqueC(SEXP x) {
   } else if (tx == LGLSXP) {
     M = 3;
   } else error("Type %s is not supported.", type2char(tx)); // # nocov
-  int *restrict h = (int*)Calloc(M, int); // Table to save the hash values, table has size M
+  int *restrict h = (int*)R_Calloc(M, int); // Table to save the hash values, table has size M
   int *restrict st = (int*)R_alloc((tx == LGLSXP || tx == 1000) ? (int)M : n, sizeof(int));
   int g = 0, nprotect = 0;
   size_t id = 0;
@@ -884,7 +884,7 @@ SEXP funiqueC(SEXP x) {
         if(++g == ng) break;
       }
     }
-    Free(h);
+    R_Free(h);
     if(g == n) return x;
     PROTECT(res = allocVector(tx == LGLSXP ? LGLSXP : INTSXP, g)); ++nprotect;
     int *restrict pres = INTEGER(res);
@@ -917,7 +917,7 @@ SEXP funiqueC(SEXP x) {
         ibbl:;
       }
     }
-    Free(h);
+    R_Free(h);
     if(g == n) {
       UNPROTECT(nprotect);
       return x;
@@ -930,7 +930,7 @@ SEXP funiqueC(SEXP x) {
     const double *restrict px = REAL(x);
     union uno tpv;
     for (int i = 0; i != n; ++i) {
-      tpv.d = px[i];
+      tpv.d = px[i]+0;
       id = HASH(tpv.u[0] + tpv.u[1], K);
       while(h[id]) {
         if(REQUAL(px[h[id]-1], px[i])) goto rbl;
@@ -940,7 +940,7 @@ SEXP funiqueC(SEXP x) {
       st[g++] = i;
       rbl:;
     }
-    Free(h);
+    R_Free(h);
     if(g == n) {
       UNPROTECT(nprotect);
       return x;
@@ -961,9 +961,9 @@ SEXP funiqueC(SEXP x) {
       } else if (C_IsNaN(tmp)) {
         tmp.r = tmp.i = R_NaN;
       }
-      tpv.d = tmp.r;
+      tpv.d = tmp.r+0;
       u = tpv.u[0] ^ tpv.u[1];
-      tpv.d = tmp.i;
+      tpv.d = tmp.i+0;
       u ^= tpv.u[0] ^ tpv.u[1];
       id = HASH(u, K);
       while(h[id]) {
@@ -974,7 +974,7 @@ SEXP funiqueC(SEXP x) {
       st[g++] = i;
       cbl:;
     }
-    Free(h);
+    R_Free(h);
     if(g == n) {
       UNPROTECT(nprotect);
       return x;
@@ -995,7 +995,7 @@ SEXP funiqueC(SEXP x) {
       st[g++] = i;
       sbl:;
     }
-    Free(h);
+    R_Free(h);
     if(g == n) {
       UNPROTECT(nprotect);
       return x;
@@ -1037,9 +1037,9 @@ SEXP funiqueC(SEXP x) {
 //     K++;
 //   }
 //   R_xlen_t count = 0;
-//   int *restrict h = (int*) Calloc(M, int);
+//   int *restrict h = (int*) R_Calloc(M, int);
 //   const int *restrict v = INTEGER(mlv);
-//   int *restrict pans = (int*) Calloc(len_i, int);
+//   int *restrict pans = (int*) R_Calloc(len_i, int);
 //   size_t id = 0;
 //
 //       for (R_xlen_t i = 0; i < len_i; ++i) {
@@ -1063,7 +1063,7 @@ SEXP funiqueC(SEXP x) {
 //         count++;
 //         label2:;
 //       }
-//     Free(h);
+//     R_Free(h);
 //     UNPROTECT(1);
 //     SEXP indx = PROTECT(allocVector(INTSXP, count));
 //     int ct = 0;
@@ -1074,7 +1074,7 @@ SEXP funiqueC(SEXP x) {
 //       }
 //     }
 //     SEXP output = PROTECT(subSetRowDataFrame(x, indx));
-//     Free(pans);
+//     R_Free(pans);
 //     UNPROTECT(2);
 //     return output;
 // }
@@ -1114,7 +1114,7 @@ SEXP funiqueC(SEXP x) {
 //     K++;
 //   }
 //   R_xlen_t count = 0;
-//   int *restrict h = (int*) Calloc(M, int);
+//   int *restrict h = (int*) R_Calloc(M, int);
 //   const int *restrict v = INTEGER(mlv);
 //   size_t id = 0;
 //   for (R_xlen_t i = 0; i < len_i; ++i) {
@@ -1137,7 +1137,7 @@ SEXP funiqueC(SEXP x) {
 //     count++;
 //     label2:;
 //   }
-//   Free(h);
+//   R_Free(h);
 //   UNPROTECT(1);
 //   return ScalarInteger(count);
 // }
